#!/usr/bin/env python

#	t00mblr - a GTK tumblr client
#	By: Jaap Broekhuizen <jaapz.b@gmail.com>
#	Website: blog.jaapz.nl
#	
#	License:
#	This file is part of t00mblr.
#
#    t00mblr is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    t00mblr is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with t00mblr.  If not, see <http://www.gnu.org/licenses/>.

'''This sends the quotes to tumblr.com'''

import gtk, pango

from tumblr import Api
from common import d
import common as c

class quote(gtk.Window):
	table = None
	api = None
	
	def __init__(self, api):
		"""
			Text window initial function
		"""
		self.api = api
		
		gtk.Window.__init__(self)
		self.create_window()
		
	def create_window(self):
		"""
			Creates the quote window
		"""
		self.set_title("Quote")
		self.set_position(gtk.WIN_POS_CENTER)
		
		# create the table
		self.table = gtk.Table(3,2,False)
		self.table.set_col_spacings(5)
		
		# add title
		textpost = gtk.Label()
		textpost.set_markup("<span size=\"20000\">Add a Quote</span>")
		
		# add source box label
		source = gtk.Label()
		source.set_markup("<span size=\"12000\">Source</span>")
		source.set_alignment(0,0)
		source_cont = gtk.VBox()
		source_cont.add(source)
		
		# add title box
		self.sourcebox = gtk.Entry()
		source_cont.add(self.sourcebox)
		
		# add text box label
		text = gtk.Label()
		text.set_markup("<span size=\"12000\">Quote</span>")
		text.set_alignment(0,0)
		text_cont = gtk.VBox()
		text_cont.add(text)
		
		# add text box
		sw = gtk.ScrolledWindow()
		sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
		textbox = gtk.TextView()
		textbox.set_size_request(300,100)
		self.textboxbuffer = textbox.get_buffer()
		
		# add text box to scrolledwindow
		sw.add(textbox)
		text_cont.add(sw)
		
		# add publish combobox
		self.publish = gtk.combo_box_new_text()
		self.publish.append_text("publish now")
		self.publish.append_text("add to qeue")
		self.publish.append_text("publish on...")
		self.publish.append_text("save as draft")
		self.publish.append_text("private")
		self.publish.set_active(0)
		self.publish.connect("changed", self.publish_changed)
		
		# add publish time
		publish_time = gtk.Label()
		publish_time.set_markup("<span size=\"12000\">Time</span>")
		publish_time.set_alignment(0,0)
		self.publish_time_entry = gtk.Entry()
		self.publish_time_cont = gtk.VBox()
		self.publish_time_cont.add(publish_time)
		self.publish_time_cont.add(self.publish_time_entry)

		# add tags box label
		tags = gtk.Label()
		tags.set_markup("<span size=\"12000\">Tags</span>")
		tags.set_alignment(0,0)
		tags_cont = gtk.VBox()
		tags_cont.add(tags)
		
		# add tags box
		sw2 = gtk.ScrolledWindow()
		sw2.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
		tagsbox = gtk.TextView()
		tagsbox.set_size_request(170,100)
		self.tagboxbuffer = tagsbox.get_buffer()
		
		# add tags box to scrolledwindow
		sw2.add(tagsbox)
		tags_cont.add(sw2)
		
		# add buttons
		self.buttons = gtk.HButtonBox()
		self.buttons.set_layout(gtk.BUTTONBOX_CENTER)
		
		cancel = gtk.Button(None, gtk.STOCK_CANCEL)
		cancel.connect("clicked", self.destroy_me)
		
		apply = gtk.Button(None, gtk.STOCK_APPLY)
		apply.connect("clicked", self.send)
		
		self.buttons.add(apply)
		self.buttons.add(cancel)
		
		# add all to the table
		self.table.attach(textpost,0,1,0,1, yoptions=0)
		self.table.attach(source_cont,0,1,1,2, yoptions=0)
		self.table.attach(text_cont,0,1,2,3, yoptions=0)
		self.table.attach(self.publish,1,2,0,1, yoptions=0, xoptions=0)
		self.table.attach(self.publish_time_cont,1,2,1,2, yoptions=0, xoptions=0)
		self.table.attach(tags_cont,1,2,2,3, yoptions=0, xoptions=0)
		
		# add table + buttons to new table
		self.buttontable = gtk.Table(1,2,False)
		self.buttontable.attach(self.table,0,1,0,1, yoptions=gtk.EXPAND)
		self.buttontable.attach(self.buttons,0,1,1,2, yoptions=0)
		self.add(self.buttontable)
		
		# and now... show it!
		self.show_all()
		
	def destroy_me(self, widget=None):
		"""
			Destroys the window
		"""
		self.destroy()
		
	def publish_changed(self, widget):
		"""
			Is called when publish combobox has changed
		"""
		active = widget.get_active()
		if (active == 1) or (active == 4):
			self.publish_time_cont.hide()
		else:
			self.publish_time_cont.show()
			
	def send(self, widget):
		"""
			Send the quote
		"""
		d.debug("Sending quote...")
		
		# get source
		source_text =  self.sourcebox.get_text()
		
		# get text
		start_text = self.textboxbuffer.get_start_iter()
		end_text = self.textboxbuffer.get_end_iter()
		text = self.textboxbuffer.get_text(start_text, end_text)
		
		# get tags
		start_tags = self.tagboxbuffer.get_start_iter()
		end_tags = self.tagboxbuffer.get_end_iter()
		tags_text = self.tagboxbuffer.get_text(start_tags, end_tags)
		
		# get state
		s = int(self.publish.get_active())
		if s == 0:
			state_text = "published"
		elif s == 1:
			state_text = "queue"
		elif s == 2:
			state_text = "queue"
		elif s == 3:
			state_text = "draft"
		elif s == 4:
			state_text = "private"
			
		# get time
		time = self.publish_time_entry.get_text()
		
		try:
			self.api.write_quote(text, source=source_text, tags=tags_text, state=state_text, publish_on=time)
			d.info("Quote sent!")
			self.destroy_me()
		except:
			d.error("Failed sending the quote. Did you fill in either a title or a post?")
		
