#!/usr/bin/env python

#	t00mblr - a GTK tumblr client
#	By: Jaap Broekhuizen <jaapz.b@gmail.com>
#	Website: blog.jaapz.nl
#	
#	License:
#	This file is part of t00mblr.
#
#    t00mblr is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    t00mblr is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with t00mblr.  If not, see <http://www.gnu.org/licenses/>.

'''This is the t00mblr main window'''

import gtk
import ConfigParser
import sys
import os
import gobject

from c00nfig import *
from view00r import *
from tumblr import *
from common import d
import common as c

sys.path.append(os.getcwd() + "/plugins")
from text import *
from quote import *
from link import *

class t00mblr:
	win = None
	table = None
	tray = None
	config = None
	auth = None
	
	config_path = "t00mblr.cfg"
	
	def main(self):
		"""
			Shows the main window
		"""
		c.config = ConfigParser.SafeConfigParser()
		
		self.create_window()

		try:
			self.auth = c.authenticate()
		except:
			d.error("Authentication gone wrong!")		
		
		gtk.main()
	
	def create_window(self):
		"""
			Creates the main window
		"""
		d.debug("Creating window")
		
		self.win = gtk.Window()
		self.win.set_title("t00mblr")
		self.win.set_icon_from_file("images/32x32.png")
		self.win.set_size_request(314, 300)
		self.win.connect("destroy", self.destroy)
		self.win.set_resizable(True)
		self.win.connect("configure-event", self.save_window_height)
		
		self.table = gtk.Table(3,1,False)
		
		self.create_menu()
		self.create_toolbar()
		self.create_view00r(self.get_blog())
		
		c.get_config()
		
		if c.config.get("Window","show_tray_icon") == "True":
			self.create_trayicon()
		
		self.win.add(self.table)
		self.win.show_all()
		
		self.win.resize(self.get_size("w"), self.get_size("h"))
		
	def create_menu(self):
		"""
			Creates the main menu
		"""
		mb = gtk.MenuBar()

		# Tumblr menu
		tumblrmenu = gtk.Menu()
		tumblr = gtk.MenuItem("_Tumblr")
		tumblr.set_submenu(tumblrmenu)
		
		# Create new status
		status = gtk.MenuItem("_Status")
		tumblrmenu.append(status)
				
		# Add Seperator
		seperator = gtk.SeparatorMenuItem()
		tumblrmenu.append(seperator)
		
		# Quit button
		exit = gtk.ImageMenuItem(gtk.STOCK_QUIT)
		exit.connect("activate", self.destroy)
		tumblrmenu.append(exit)

		mb.append(tumblr)
		
		# Edit menu
		editmenu = gtk.Menu()
		edit = gtk.MenuItem("_Edit")
		edit.set_submenu(editmenu)
		
		# Edit preferences
		preferences = gtk.ImageMenuItem(gtk.STOCK_PREFERENCES)
		preferences.connect("activate", self.show_config)
		editmenu.append(preferences)
		
		mb.append(edit)
		
		# Help menu
		helpmenu = gtk.Menu()
		help = gtk.MenuItem("_Help")
		help.set_submenu(helpmenu)
		
		# About
		about = gtk.ImageMenuItem(gtk.STOCK_ABOUT)
		about.connect("activate", self.aboutdialog)
		helpmenu.append(about)
		
		mb.append(help)

		# Pack it all in a nice box
		vbox = gtk.VBox(False, 2)
		vbox.pack_start(mb, False, False, 0)

		self.table.attach(vbox,0,1,0,1)
		
	def create_toolbar(self):
		"""
			Creates the toolbar
		"""
		tb = gtk.Toolbar()
		
		# Text
		textimage = gtk.Image()
		textimage.set_from_file("images/text.png")
		text = gtk.ToolButton(textimage, "Text")
		text.connect("clicked", self.show_text_window)
		
		# Images
		imgimage = gtk.Image()
		imgimage.set_from_file("images/image.png")
		img = gtk.ToolButton(imgimage, "Image")
		
		# Quotes
		quoteimage = gtk.Image()
		quoteimage.set_from_file("images/quote.png")
		quote = gtk.ToolButton(quoteimage, "Quote")
		quote.connect("clicked", self.show_quote_window)
		
		# Links
		linkimage = gtk.Image()
		linkimage.set_from_file("images/link.png")
		link = gtk.ToolButton(linkimage, "Url")
		link.connect("clicked", self.show_link_window)
		
		# Chats
		chatimage = gtk.Image()
		chatimage.set_from_file("images/chat.png")
		chat = gtk.ToolButton(chatimage, "Chat")
		
		# Audio
		audimage = gtk.Image()
		audimage.set_from_file("images/audio.png")
		audio = gtk.ToolButton(audimage, "Audio")
		
		# Video
		vidimage = gtk.Image()
		vidimage.set_from_file("images/video.png")
		video = gtk.ToolButton(vidimage, "Video")
		
		# Add buttons to toolbar
		tb.insert(text, 0)
		tb.insert(img, 1)
		tb.insert(quote, 2)
		tb.insert(link, 3)
		tb.insert(chat, 4)
		tb.insert(audio, 5)
		tb.insert(video, 6)
		
		# Add toolbar to container
		vbox = gtk.VBox(False, 0)
		vbox.pack_start(tb, False, False, 0)
		
		width, height = self.win.get_size()
		vbox.set_size_request(width, 47)
		
		# Add container to table
		self.table.attach(vbox,0,1,1,2, yoptions=0)
		
	def create_view00r(self, content):
		"""
			Create the tumblr stream viewer
		"""
		browser = view00r(self, content)
		
		vbox = gtk.VBox(False, 0)
		vbox.pack_start(browser, True, True, 0)
		
		self.table.attach(vbox,0,1,2,3)
		
	def create_trayicon(self):
		"""
			Creates the trayicon
		"""
		self.tray = gtk.status_icon_new_from_file("images/32x32.png")
		self.tray.set_visible(True)
		self.tray.connect("popup-menu", self.tray_menu)
		self.tray.connect("activate", self.hide_show)
		
	def tray_menu(self, widget, button, activate_time):
		"""
			Shows the tray context menu
		"""
		menu = gtk.Menu()
		
		# Config
		preferences = gtk.ImageMenuItem(gtk.STOCK_PREFERENCES)
		preferences.connect("activate", self.show_config)
		menu.append(preferences)
		
		# Seperator
		seperator = gtk.SeparatorMenuItem()
		menu.append(seperator)
		
		# Quit button
		exit = gtk.ImageMenuItem(gtk.STOCK_QUIT)
		exit.connect("activate", self.destroy)
		menu.append(exit)
		
		# Lets show our menu!
		menu.show_all()
		menu.popup(None, None, None, button, activate_time)
		
	def aboutdialog(self, widget):
		"""
			Shows the about window
		"""
		logo = gtk.gdk.pixbuf_new_from_file("images/64x64.png");
		
		dialog = gtk.AboutDialog()
		dialog.set_logo_icon_name("t00mblr")
		dialog.set_logo(logo)
		dialog.set_name("t00mblr")
		dialog.set_comments("A gtk+ tumblr client")
		dialog.set_copyright("Copyright (c) 2010 Jaap Broekhuizen")
		dialog.set_version("trunk")
		dialog.set_website_label("http://t00mblr.jaapz.nl")
		dialog.set_website("http://t00mblr.jaapz.nl")
		dialog.set_license('''t00mblr is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

t00mblr is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with t00mblr.  If not, see <http://www.gnu.org/licenses/>.''')
		
		dialog.set_authors(["Jaap Broekhuizen <jaapz.b@gmail.com>\n	Main developer\n	http://www.jaapz.nl\n",
							"Ryan Cox <ryan.a.cox@gmail.com>\n	Tumblr Api Library"])
		dialog.set_artists(["Ajith R <ajithr.tk@gmail.com>\n	Logo design\n	http://www.ajithr.tk"])
		dialog.run()
		dialog.destroy()
		
	def show_config(self, widget):
		"""
			Shows the config window
		"""
		configwindow = c00nfig()
		
	def get_config(self):
		"""
			Gets the configuration
		"""
		self.config = ConfigParser.SafeConfigParser()
		self.config.read(self.config_path)
	
	def save_config(self, file):
		"""
			Saves the config
		"""
		try:
			file = open(c.config_path, "wb")
			self.config.write(file)
			file.close()
		except:
			d.error("Can't save config, does the file have writing permissions?")
		
	def hide_show(self, widget):
		"""
			Hides or shows the main window
		"""
		visible = self.win.get_property("visible")
		if visible == True:
			self.win.hide()
		else:
			self.win.show_all()
			
	def show_text_window(self, widget):
		"""
			Show text window
		"""
		textwindow = text(self.auth)
		
	def show_quote_window(self, widget):
		"""
			Show quote window
		"""
		quotewindow = quote(self.auth)
		
	def show_link_window(self, widget):
		"""
			Show link window
		"""
		linkwindow = link(self.auth)
		
	def save_window_height(self, widget, event):
		"""
			Saves height and width for later
		"""
		self.get_config()
		
		self.config.set("Window", "height", str(event.height))
		self.config.set("Window", "width", str(event.width))
		
		self.save_config(self.config_path)
		
	def get_size(self, param):
		"""
			Gets window size from config
		"""
		self.get_config()
		
		if param == "h":
			return int(self.config.get("Window", "height"))
		else:
			return int(self.config.get("Window", "width"))
			
	def get_blog(self):
		"""
			Gets blog from config
		"""
		self.get_config()
		return self.config.get("User", "blog")
		
	def destroy(self, widget=None, data=None):
		gtk.main_quit()
		
if __name__ == "__main__":
	gobject.set_application_name("t00mblr")
	client = t00mblr()
	client.main()
	sys.exit(0)
	
